@@ -333,6 +333,11 @@ sqlite_st_execute (SV *sth, imp_sth_t *imp_sth)
 
     /* warn("execute\n"); */
 
+    if (!DBIc_ACTIVE(imp_dbh)) {
+        sqlite_error(sth, (imp_xxh_t*)imp_sth, retval, "attempt to execute on inactive database handle");
+        return FALSE;
+    }
+
     if (DBIc_ACTIVE(imp_sth)) {
          sqlite_trace(3, "execute still active, reset");
          if ((imp_sth->retval = sqlite3_reset(imp_sth->stmt)) != SQLITE_OK) {
@@ -426,6 +431,7 @@ sqlite_st_execute (SV *sth, imp_sth_t *imp_sth)
                           return 0;
                           /* There are bug reports that say this should be sqlite3_reset() */
         default:          sqlite3_finalize(imp_sth->stmt);
+                          imp_sth->stmt = NULL;
                           sqlite_error(sth, (imp_xxh_t*)imp_sth, imp_sth->retval, (char*)sqlite3_errmsg(imp_dbh->db));
                           return -6;
     }
